#!/usr/bin/env python
#
# pycdda/__init__.py
#
# Copyright (c) 2001 Alan Eldridge. All rights reserved.
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the "Artistic License" which is 
# distributed with the software in the file LICENSE.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Artistic
# License for more details.
# 
# $Id$
#
# 2001/05/26 jalane@sourceforge.net
#

import os

import pycdda.version
import pycdda.impl.linux

class device:
    """Abstract device class.

    Knows nothing about CD drives. All real work
    is delegated to an impl object, which is part
    of pycdda.impl.
    
    A device can open() a file, returning an
    implementation object to access the CD drive.
    """

    impl = pycdda.impl.linux.cdrom
    oflags = os.O_RDONLY|os.O_NONBLOCK

    def __init__(self, name = None, scsi = None):
        """Constructor.

        name => device file
          [e.g., "/dev/cdrom"]
        """
        if not name:
            name = "cdrom"
        if name[0] != "/":
            name = "/dev/" + name

        self.name = name
        self.scsi = scsi
        
    def open(self):
        """Open the device.

        This returns an implementation. The
        open fd is bound to the "impl" object.
        The only way to close the file is to
        use the builtin del.
        """
        try:
            os.stat(self.name)
        except:
            pass
        try:
            fd = os.open(self.name, self.oflags)
        except:
            return None
        return self.impl(fd)

#
#EOF
##
