#!/usr/bin/env python
#
# pycdda/disc.py
#
# Copyright (c) 2001 Alan Eldridge. All rights reserved.
# 
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the "Artistic License" which is 
# distributed with the software in the file LICENSE.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Artistic
# License for more details.
# 
# $Id$
#
# 2001/05/29 jalane@sourceforge.net
#

############################################################
# pos
#   position on disc in terms of track + offset
############################################################

class pos:
    """Current track and locn within it.
    iTrk => int
      [0 based]
    trkMSF => msf
    trkFrm => int
    """
    pass
    
############################################################
# TOC
#   table of contents of a CDDA disc
#
# discid: algorithm from freedb.org developer's HOWTO
############################################################

def cddb_sum(n):
    ret = 0
    while n > 0:
        ret = ret + (n % 10)
        n = n / 10
    return ret

class TOC:
    """Disc Table Of Contents
    
    maxTrk => int
      [0 based]
    rgTrk => [trkinfo]
      [0 based]
    tochdr => (beg,end)
      [1-based]
    mpTrk => {indx:trkinfo}
      [1-based]
    """
    def discid(self):
        n = 0
        for i in self.rgTrk[:-1]:
            n = n + cddb_sum(i.locFrm / 75)
        t = self.rgTrk[-1].locFrm / 75 - self.rgTrk[0].locFrm / 75
        return (n % 0xff) << 24 | t << 8 | self.maxTrk

############################################################
# track
#   data about a single track in toc
############################################################

class track:
    """Track Entry in TOC.

    indx => int
    [1 based]
    type => str
      ["audio", "data"]
    locMSF => msf
    locFrm => int
    lenMSF => msf
    lenFrm => int
    lenSec => int
    lenMinSec => (int,int)
    """
    def frames(self):
        return (self.locFrm, self.locFrm + self.lenFrm - 1)
    
############################################################
# info
#   the current state of the device (if there is an
#   an audio disc loaded...)
############################################################

class info:
    """Info about the current CDDA disc.

    mode => str
      ["","play","pause","done"]
    locMSF => msf
    locFrm => int

    *** TOC ***
    toc => TOC
    lenMSF => msf
    lenFrm => int
    curTrk => pos
    """

#
#EOF
##
